/***********************************************************************\
*
* $Source$
* $Revision$
* $Author$
* Contents: SWT with embedded native OpenGL demo
* Systems: all
*
\***********************************************************************/

/****************************** Imports ********************************/
import org.eclipse.swt.*;
import org.eclipse.swt.widgets.*;
import org.eclipse.swt.layout.*;
import org.eclipse.swt.events.*;
import org.eclipse.swt.graphics.*;

/****************************** Classes ********************************/

/* very simple OpenGL native interface */
class OpenGL
{
  public static native void openGL_init(int windowId, int width, int height);
  public static native void openGL_done();

  public static native void openGL_resize(int width, int height);
  public static native void openGL_draw();
  public static native void openGL_animate();
}

/* drawing and animator thread */
class AnimatorThread extends Thread
{
  private Composite composite;

  AnimatorThread(Composite composite)
  {
    this.composite = composite;
  }

  public void run()
  {
    while (!composite.isDisposed())
    {
      /* draw */
      composite.getDisplay().syncExec(new Runnable()
      {
        public void run()
        {
          OpenGL.openGL_animate();
        }
      });

      /* sleep a short time */
      try { Thread.sleep(50); } catch (InterruptedException exception) {}
    }
  }
}

public class OpenGLTest
{
  // --------------------------- constants --------------------------------

  // --------------------------- variables --------------------------------
  static Shell shell;

  // ------------------------ native functions ----------------------------

  // ---------------------------- methods ---------------------------------
  public static void main(String[] args)
  {
    Composite composite;
    Label     label;
    Button    button;

    /* load native OpenGL interface library */
    System.load(System.getProperty("OpenGLLibrary"));

    /* create SWT window with widgets */
    Display display = new Display();
    shell = new Shell(display);
    shell.setText("SWT with Mesa OpenGL");
    shell.setLayout(new TableLayout(new double[]{1.0,0.0},new double[]{1.0,0.0},2));

    composite = new Composite(shell,SWT.BORDER|SWT.EMBEDDED|SWT.NO_BACKGROUND);
    composite.setLayoutData(new TableLayoutData(0,0,TableLayoutData.NSWE|TableLayoutData.EXPAND));
    composite.addControlListener(new ControlListener()
    {
      public void controlMoved(ControlEvent controlEvent)
      {
      }
      public void controlResized(ControlEvent controlEvent)
      {
        Composite composite = (Composite)controlEvent.widget;
        Rectangle bounds = composite.getClientArea();
        OpenGL.openGL_resize(bounds.width,bounds.height);
      }
    });

    button = new Button(shell,SWT.PUSH);
    button.setText("OK");
    button.setLayoutData(new TableLayoutData(1,0,TableLayoutData.WE));
    button.addSelectionListener(new SelectionListener()
    {
      public void widgetSelected(SelectionEvent selectionEvent)
      {
        Button widget = (Button)selectionEvent.widget;
        shell.close();
      }
      public void widgetDefaultSelected(SelectionEvent selectionEvent)
      {
      }
    });

    shell.setSize(600,600);
    shell.open();

    /* init native OpenGL interface code */
    Rectangle bounds = composite.getBounds();
    OpenGL.openGL_init(composite.embeddedHandle,
                       bounds.width,
                       bounds.height
                      );

    /* start drawing and animator thread */
    new AnimatorThread(composite).start();

    /* SWT event loop */
    while (!shell.isDisposed())
    {
      if (!display.readAndDispatch())
      {
        display.sleep();
      }
    }
  }
}

/* end of file */
